Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1223)

Unified Diff: Source/core/layout/LayoutMultiColumnFlowThread.h

Issue 1124133002: Rename findSetLayoutObjects() to mapDescendantToColumnSet() (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/core/layout/LayoutMultiColumnFlowThread.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/layout/LayoutMultiColumnFlowThread.h
diff --git a/Source/core/layout/LayoutMultiColumnFlowThread.h b/Source/core/layout/LayoutMultiColumnFlowThread.h
index baff32b39619ebe1514abb147f88aaa2bcd2f489..6ef247e30653e95addbe571d9634ce513466a879 100644
--- a/Source/core/layout/LayoutMultiColumnFlowThread.h
+++ b/Source/core/layout/LayoutMultiColumnFlowThread.h
@@ -142,8 +142,8 @@ public:
return lastSiblingBox != this ? lastSiblingBox : 0;
}
- // Find the first set inside which the specified layoutObject would be rendered.
- LayoutMultiColumnSet* findSetLayoutObjects(LayoutObject*) const;
+ // Find the first set inside which the specified layoutObject (which is a flowthread descendant) would be rendered.
+ LayoutMultiColumnSet* mapDescendantToColumnSet(LayoutObject*) const;
// Return the spanner placeholder that belongs to the spanner in the containing block chain, if
// any. This includes the layoutObject for the element that actually establishes the spanner too.
« no previous file with comments | « no previous file | Source/core/layout/LayoutMultiColumnFlowThread.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698